function Mesh = discretizeMeander(Poly, MeshDensity)
%% AToM wrapper for Delaunay discretization of a meanderline antenna
% 
% Poly        ~ polygon [X Y Z] coordinates
% MeshDensity ~ the length of discretization elements
% 
% Mesh        ~ static structure containing discretization
% 
% Miloslav apek, CTU in Prague, miloslav.capek@fel.cvut.cz
% AToM example, info@antennatoolbox.com
% 2018-2019

% Name of temporary file (to be deleted after the mesh generation)
fileName = ['TEMPfile_AToM_meanderDiscretization' num2str(randi(1e9, 1, 1))];
% Start AToM, create a new project
atom = Atom.start(false);
atom.createProject(fileName);

% Add predefined polygon
atom.selectedProject.geom.addPolygon([Poly.x, Poly.y, Poly.z]);

% Enforce YZ symmetry of resulting mesh grid
atom.selectedProject.physics.symmetryPlanes.YZ.setType('geometric');
% Do not use frequency to estimate size of discretization elements
atom.selectedProject.mesh.setElementSizeFromFrequency(false);
% Use maximum length of triangle edge
atom.selectedProject.mesh.setGlobalMeshDensity(MeshDensity);
% Do not optimize mesh for high quality (problematic for thin-strip structures)
atom.selectedProject.mesh.setQualityPriority(false);
% Discretize polygon
atom.selectedProject.mesh.getMesh;

% Get static structure of mesh from AToM
Mesh = atom.selectedProject.mesh.getMeshData2D;

% Close AToM and delete temporary file
atom.closeProject(fileName);
try delete([fileName '.atom']); catch, disp('File was not deleted.'); end