function OP = evaluateOperators(Mesh, BF, f, options)

tst = @(thisField) exist('options', 'var') && isstruct(options) && isfield(options, thisField);

if tst('Nquad')
    Nquad = options.Nquad;
else
    Nquad = 3;
end

Rs = ones(Mesh.nTriangles, 1);
if tst('Rs')
    Rs = options.Rs * Rs;
end

theta = 0;
phi   = 0;
component = 'total'; % {'theta','phi','total'}
verb  = 2;

%% Settings
settings = struct(...
    'quadOrder', Nquad, ...
    'nBatchMax', 5e3, ...
    'nWorkers', 0, ...
    'resultPath', pwd, ...
    'resultsInRAM', true, ...
    'resultsInFile', false, ...
    'verbosity', verb);
requests = {'mesh', 'basisFcns', 'zMat', 'zMatM0', 'zMatE0', 'zMatD'};

%% MoM calculation
nFreq = length(f);
Res   = models.solvers.MoM2D.solve(...
    Mesh, f, [], [], [1 1 1], settings, requests, []);

% Initial data
OP.Mesh = Mesh;
OP.BF   = BF;
OP.f0   = f;

% Impedance matrix, static parts of impedance matrix
OP.Z      = Res.zMat.data;
OP.zMatM0 = Res.zMatM0.data;
OP.zMatE0 = Res.zMatE0.data;

% Stored energy matrix operator
OP.omW  = nan(BF.nUnknowns, BF.nUnknowns, nFreq);
OP.omDZ = nan(BF.nUnknowns, BF.nUnknowns, nFreq);
for fi = 1:nFreq
    OP.omW(:,:,fi)  = 2*pi*f(fi)*imag(Res.zMatD.data(:,:,fi));
    OP.omDZ(:,:,fi) = 2*pi*f(fi)*Res.zMatD.data(:,:,fi);
end

% Far field radiation matrix operator
OP.U = nan(BF.nUnknowns, BF.nUnknowns, nFreq);
for fi = 1:nFreq
    [OP.U(:,:,fi), OP.Fphi(fi, :), OP.Ftheta(fi, :)] = ...
        models.utilities.matrixOperators.farfield.computeU...
        (Mesh, BF, f(fi), theta, phi, component, Nquad);
end

% Lossy matrix operator
OP.L = models.utilities.matrixOperators.ohmicLosses.lossyMatrix(Mesh, BF, Rs);

% Plane wave projection matrix operator
k = models.utilities.converter.f0tok0(f);
Lmax = models.utilities.matrixOperators.SMatrix.lmax(k*Mesh.normDistanceA);
OP.S = zeros(2*max(Lmax)*(max(Lmax)+2), BF.nUnknowns, nFreq);
for fi = 1:nFreq
    OP.S(1:(2*Lmax(fi)*(Lmax(fi)+2)),:,fi) = ...
        models.utilities.matrixOperators.SMatrix.computeS(...
        Mesh, BF, f(fi), Lmax(fi), Nquad);
end