function [P, N] = generateMeanders(L, H, s, w, wmax, varargin)
% Lukas Jelinek, FEL-CVUT

wfeed=min(wmax, w); % width of the feeding edge
Lfeed=(w/2-wfeed/2); % length of the feeding taper - 45 Deg angle fo the tapper

nVarargs = length(varargin);

if nVarargs == 0
N=floor(L/2/(w+s)); % number of meanders in L/2
else
    N=varargin{1};
    if N > floor(L/2/(w+s))
    N=floor(L/2/(w+s)); % number of meanders in L/2
    end
end

tol = w/1e1; % 1e1

if floor(N/2)==N/2 % odd number of meanders, feeding point is down  
    %%%%%%%%% first edge %%%%%%%%%%%%%%
    x1=[0];
    y1=[0];
    
    for i_turn=1:N/2
        x1=[x1,([0,0,2*w+s,2*w+s]+(i_turn-1)*(2*w+2*s))];
        y1=[y1,[w,H,H,w]];
    end
    
    x1=x1-L/2;
    y1=y1-H/2;
    
    if Lfeed < tol
        x1=[x1,0,flip(-x1)];
        y1=[y1,-H/2+w,flip(y1)];
    else
        x1=[x1,0-Lfeed,0,0+Lfeed,flip(-x1)];
        y1=[y1,-H/2+w,-H/2+w/2+wfeed/2,-H/2+w,flip(y1)];
    end
    %%%%%%%%% first edge %%%%%%%%%%%%%%
    
    %%%%%%%%% second edge %%%%%%%%%%%%%%
    x2=[];
    y2=[];
    
    for i_turn=1:N/2
        x2=[x2,([w,w,w+s,w+s]+(i_turn-1)*(2*w+2*s))];
        y2=[y2,[0,H-w,H-w,0]];
    end
    
    x2=x2-L/2;
    y2=y2-H/2;
    
    if Lfeed < tol
        x2=[x2,0,flip(-x2)];
        y2=[y2,-H/2,flip(y2)];
    else
        x2=[x2,0-Lfeed,0,0+Lfeed,flip(-x2)];
        y2=[y2,-H/2,-H/2+w/2-wfeed/2,-H/2,flip(y2)];
    end
    %%%%%%%%% second edge %%%%%%%%%%%%%%
    
else % even number of meanders, feeding point is down
    
    %%%%%%%%% first edge %%%%%%%%%%%%%%
    x1=[0];
    y1=[0];
    
    for i_turn=1:(N-1)/2
        x1=[x1,([0,0,2*w+s,2*w+s]+(i_turn-1)*(2*w+2*s))];
        y1=[y1,[w,H,H,w]];
    end
    
    x1=[x1,([2*w+2*s,2*w+2*s]+(N-3)*(w+s))];
    y1=[y1,[w,H]];
    
    x1=x1-L/2;
    y1=y1-H/2;
    
    if Lfeed < tol
        x1=[x1,0,flip(-x1)];
        y1=[y1,H/2,flip(y1)];
    else
        x1=[x1,0-Lfeed,0,0+Lfeed,flip(-x1)];
        y1=[y1,H/2,H/2-w/2+wfeed/2,H/2,flip(y1)];
    end
    %%%%%%%%% first edge %%%%%%%%%%%%%%
    
    %%%%%%%%% second edge %%%%%%%%%%%%%%
    x2=[];
    y2=[];
    
    for i_turn=1:(N-1)/2
        x2=[x2,([w,w,w+s,w+s]+(i_turn-1)*(2*w+2*s))];
        y2=[y2,[0,H-w,H-w,0]];
    end
    
    x2=[x2,([3*w+2*s,3*w+2*s]+(N-3)*(w+s))];
    y2=[y2,[0,H-w]];
    
    x2=x2-L/2;
    y2=y2-H/2;
    
    if Lfeed < tol
        x2=[x2,0,flip(-x2)];
        y2=[y2,H/2-w,flip(y2)];
    else
        x2=[x2,0-Lfeed,0,0+Lfeed,flip(-x2)];
        y2=[y2,H/2-w,H/2-w+w/2-wfeed/2,H/2-w,flip(y2)];
    end
    %%%%%%%%% second edge %%%%%%%%%%%%%%
end

P.x = [x1,flip(x2)].';
P.y = [y1,flip(y2)].';
P.z = zeros(size(P.y));