function [x, y] = newton(x0, x, f, N, tol, err)
%% Newton method (back-step derivation)
% 
% x0  ~ initial point (x0)
% x   ~ initial guess (x0+dx)
% f   ~ functional handle function to be searched in
% N   ~ maximum number of steps
% tol ~ tolerance
% err ~ handle to calculate tolerance (e.g., err = @(y) abs(y))
%       variable to work with in the handle: y, y0, x, x0
% 
% M.C. (2017)

y  = inf;
y0 = f(x0);
n  = 1;
t = tic;
fprintf('-------------------------------\n');
while (err(y) > tol) && (n < N)
    y  = f(x);
    dy = (y - y0)/(x-x0);
    x0 = x;
    y0 = y;
    x = x - y/dy;
    
    fprintf('i: %2.0f | x: %15f | f(x) = %15f || ti-t0 = %.1fs \n', n, x, y, toc(t));
    n = n + 1;
end